diff --git a/src/main/resources/fess_config.properties b/src/main/resources/fess_config.properties
index 5bea5fd1b..444123d41 100644
--- a/src/main/resources/fess_config.properties
+++ b/src/main/resources/fess_config.properties
@@ -235,9 +235,9 @@ indexer.webfs.commit.margin.time=5000
indexer.webfs.max.empty.list.count=3600
indexer.webfs.update.interval=10000
indexer.webfs.max.document.cache.size=10
-indexer.webfs.max.document.request.size=10485760
+indexer.webfs.max.document.request.size=1048576
indexer.data.max.document.cache.size=5
-indexer.data.max.document.request.size=10485760
+indexer.data.max.document.request.size=1048576
indexer.language.fields=content,important_content,title
indexer.language.detect.length=1000
diff --git a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
index a31de06af..e0cbe4e25 100644
--- a/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
+++ b/src/main/java/org/codelibs/fess/mylasta/direction/FessConfig.java
@@ -396,13 +396,13 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/** The key of the configuration. e.g. 10 */
String INDEXER_WEBFS_MAX_DOCUMENT_CACHE_SIZE = "indexer.webfs.max.document.cache.size";
/** The key of the configuration. e.g. 10485760 */
String INDEXER_WEBFS_MAX_DOCUMENT_REQUEST_SIZE = "indexer.webfs.max.document.request.size";
/** The key of the configuration. e.g. 5 */
String INDEXER_DATA_MAX_DOCUMENT_CACHE_SIZE = "indexer.data.max.document.cache.size";
/** The key of the configuration. e.g. 10485760 */
String INDEXER_DATA_MAX_DOCUMENT_REQUEST_SIZE = "indexer.data.max.document.request.size";
/** The key of the configuration. e.g. content,important_content,title */
@@ -2577,14 +2577,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.webfs.max.document.request.size'.
* The value is, e.g. 10485760
* @return The value of found property. (NotNull: if not found, exception but basically no way)
*/
String getIndexerWebfsMaxDocumentRequestSize();
/**
* Get the value for the key 'indexer.webfs.max.document.request.size' as {@link Integer}.
* The value is, e.g. 10485760
* @return The value of found property. (NotNull: if not found, exception but basically no way)
* @throws NumberFormatException When the property is not integer.
*/
@@ -2607,14 +2607,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.data.max.document.request.size'.
* The value is, e.g. 10485760
* @return The value of found property. (NotNull: if not found, exception but basically no way)
*/
String getIndexerDataMaxDocumentRequestSize();
/**
* Get the value for the key 'indexer.data.max.document.request.size' as {@link Integer}.
* The value is, e.g. 10485760
* @return The value of found property. (NotNull: if not found, exception but basically no way)
* @throws NumberFormatException When the property is not integer.
*/
@@ -8461,9 +8461,9 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
defaultMap.put(FessConfig.INDEXER_WEBFS_MAX_EMPTY_LIST_COUNT, "3600");
defaultMap.put(FessConfig.INDEXER_WEBFS_UPDATE_INTERVAL, "10000");
defaultMap.put(FessConfig.INDEXER_WEBFS_MAX_DOCUMENT_CACHE_SIZE, "10");
- defaultMap.put(FessConfig.INDEXER_WEBFS_MAX_DOCUMENT_REQUEST_SIZE, "10485760");
+ defaultMap.put(FessConfig.INDEXER_WEBFS_MAX_DOCUMENT_REQUEST_SIZE, "1048576");
defaultMap.put(FessConfig.INDEXER_DATA_MAX_DOCUMENT_CACHE_SIZE, "5");
- defaultMap.put(FessConfig.INDEXER_DATA_MAX_DOCUMENT_REQUEST_SIZE, "10485760");
+ defaultMap.put(FessConfig.INDEXER_DATA_MAX_DOCUMENT_REQUEST_SIZE, "1048576");
defaultMap.put(FessConfig.INDEXER_LANGUAGE_FIELDS, "content,important_content,title");
defaultMap.put(FessConfig.INDEXER_LANGUAGE_DETECT_LENGTH, "1000");
defaultMap.put(FessConfig.INDEX_CODEC, "default");
@@ -396,13 +396,13 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/** The key of the configuration. e.g. 10 */
String INDEXER_WEBFS_MAX_DOCUMENT_CACHE_SIZE = "indexer.webfs.max.document.cache.size";
- /** The key of the configuration. e.g. 10485760 */
+ /** The key of the configuration. e.g. 1048576 */
String INDEXER_WEBFS_MAX_DOCUMENT_REQUEST_SIZE = "indexer.webfs.max.document.request.size";
/** The key of the configuration. e.g. 5 */
@@ -396,13 +396,13 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/** The key of the configuration. e.g. 5 */
String INDEXER_DATA_MAX_DOCUMENT_CACHE_SIZE = "indexer.data.max.document.cache.size";
- /** The key of the configuration. e.g. 10485760 */
+ /** The key of the configuration. e.g. 1048576 */
String INDEXER_DATA_MAX_DOCUMENT_REQUEST_SIZE = "indexer.data.max.document.request.size";
/** The key of the configuration. e.g. content,important_content,title */
@@ -2577,14 +2577,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.webfs.max.document.request.size'.
- * The value is, e.g. 10485760
+ * The value is, e.g. 1048576
* @return The value of found property. (NotNull: if not found, exception but basically no way)
*/
@@ -2577,14 +2577,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.webfs.max.document.request.size' as {@link Integer}.
- * The value is, e.g. 10485760
+ * The value is, e.g. 1048576
* @return The value of found property. (NotNull: if not found, exception but basically no way)
* @throws NumberFormatException When the property is not integer.
@@ -2607,14 +2607,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.data.max.document.request.size'.
- * The value is, e.g. 10485760
+ * The value is, e.g. 1048576
* @return The value of found property. (NotNull: if not found, exception but basically no way)
*/
@@ -2607,14 +2607,14 @@ public interface FessConfig extends FessEnv, org.codelibs.fess.mylasta.direction
/**
* Get the value for the key 'indexer.data.max.document.request.size' as {@link Integer}.
- * The value is, e.g. 10485760
+ * The value is, e.g. 1048576
* @return The value of found property. (NotNull: if not found, exception but basically no way)
* @throws NumberFormatException When the property is not integer.